@@ -6,7 +6,7 @@
     
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: general_parameters.h,v 1.1 2006/04/09 16:40:25 cepek Exp $
+ *  $Id: general_parameters.h,v 1.3 2007/06/26 15:04:07 cepek Exp $
  */
 
 #ifndef GaMa_GaMaProg_Zakladni_Parametry_h_
@@ -175,7 +175,7 @@ bool GeneralParameters(GaMaLib::LocalNetwork* IS, OutStream& out)
     n = strlen(T_GaMa_gpar1_angles);           if (n > w1) w1 = n;
     n = strlen(T_GaMa_gpar1_distances);        if (n > w1) w1 = n;
     n = strlen(T_GaMa_gpar1_observed_coords);  if (n > w1) w1 = n;
-    n = strlen(T_GaMa_gpar1_levelling_diffs);  if (n > w1) w1 = n;
+    n = strlen(T_GaMa_gpar1_leveling_diffs);  if (n > w1) w1 = n;
     n = strlen(T_GaMa_gpar1_z_angles);         if (n > w1) w1 = n;
     n = strlen(T_GaMa_gpar1_s_dists);          if (n > w1) w1 = n;
     n = strlen(T_GaMa_gpar1_obs_total);        if (n > w1) w1 = n;
@@ -237,7 +237,7 @@ bool GeneralParameters(GaMaLib::LocalNetwork* IS, OutStream& out)
     }
   if (pocnivp && (pocnivp != IS->sum_observations()))
     {
-      out << set_width(T_GaMa_gpar1_levelling_diffs, w1) << ":"
+      out << set_width(T_GaMa_gpar1_leveling_diffs, w1) << ":"
           << setw(6) << pocnivp << '\n';
     }
   if (poczeni)
