@@ -6,7 +6,7 @@
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
@@ -20,14 +20,14 @@
 */
 
 /*
- * $Id: adj_chol.h,v 1.4 2006/08/26 13:23:30 cepek Exp $
+ * $Id: adj_chol.h,v 1.7 2007/06/26 15:04:09 cepek Exp $
  */
 
 #ifndef GNU_gama_adjustment_cholesky_decomposition_gnu_gama_adj_chol__h
 #define GNU_gama_adjustment_cholesky_decomposition_gnu_gama_adj_chol__h
 
 #include <gnu_gama/exception.h>
-#include <gnu_gama/adj/adj_base.h>
+#include <gnu_gama/adj/adj_basefull.h>
 #include <gnu_gama/sparse/intlist.h>
 #include <matvec/inderr.h>
 #include <matvec/symmat.h>
