@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: dataparser_g3.cpp,v 1.3 2007/06/26 15:04:11 cepek Exp $
+ *  $Id: dataparser_g3.cpp,v 1.5 2009/08/16 19:23:32 cepek Exp $
  */
 
 
@@ -96,6 +96,10 @@ void DataParser::init_g3()
        s_g3_const_conf_level, 0, s_g3_const,
        0, &DataParser::add_text, &DataParser::g3_const_conf_level);
 
+  init(s_g3_const, t_tol_abs,
+       s_g3_const_tol_abs, 0, s_g3_const,
+       0, &DataParser::add_text, &DataParser::g3_const_tol_abs);
+
   init(s_g3_const, t_ang_degrees,
        s_g3_const_ang, 0, s_g3_const,
        0, 0, &DataParser::g3_const_ang_degrees);
@@ -1061,7 +1065,7 @@ int DataParser::g3_obs_vector(const char *name)
       return end_tag(name);
     }
   
-  return error("### bad <vector>");
+  return error("### bad <vector> from to dx dy dz : " + text_buffer);
 }
 
 int DataParser::g3_obs_xyz(const char *name)
@@ -1175,6 +1179,24 @@ int DataParser::g3_const_conf_level(const char *name)
   return error("### bad <confidence-level>");
 }
 
+int DataParser::g3_const_tol_abs(const char *name)
+{
+  using namespace g3;  
+  stringstream istr(text_buffer);
+  double       ta;
+
+  if (pure_data(istr >> ta))
+   {
+     text_buffer.clear();
+ 
+     g3->model->set_tol_abs(ta);
+     
+     return  end_tag(name);
+   }
+
+  return error("### bad <tol-abs>");
+}
+
 int DataParser::g3_const_ellipsoid_id(const char *name)
 {
   using namespace g3;  
