@@ -6,7 +6,7 @@
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: localnetwork_adjustment_results.h,v 1.3 2006/05/14 11:06:24 cepek Exp $
+ *  $Id: localnetwork_adjustment_results.h,v 1.7 2007/06/26 15:04:11 cepek Exp $
  */
 
 #ifndef GNU_gama_localnetwork_adjustment_results__gnugamalocalnetworkadjres_h
@@ -45,10 +45,14 @@ namespace GNU_gama
 
     void read_xml(std::istream&) throw(Exception::parser);
 
+    bool gons;
     std::string description;
     
     struct 
     {
+      std::string gama_local_version;
+      std::string gama_local_algorithm;
+      std::string gama_local_compiler;
       std::string epoch;
       std::string axes_xy;
       std::string angles;
@@ -139,6 +143,8 @@ namespace GNU_gama
 
     CovMat<> cov;
 
+    std::vector<int> original_index; // original indexes from the adjustment
+
     struct Observation
     {
       std::string xml_tag;
@@ -150,24 +156,26 @@ namespace GNU_gama
       double obs;               // observed value
       double adj;               // adjusted
       double stdev;             // standard deviation of adj. value
+      double qrr;               // weight coefficient of the residual
       double f;
 
-      std::string std_residual; // standardized residual
+      double      std_residual; // standardized residual
       std::string err_obs;      // estimate of observed value error
       std::string err_adj;      //  ....       adjusted  ....
 
       void clear()
       {
-        obs = adj = stdev = f = 0;
+        obs = adj = stdev = qrr = f = std_residual = 0;
         xml_tag     .clear();
         from        .clear();
         to          .clear();
         left        .clear();
         right       .clear();
-        std_residual.clear();
         err_obs     .clear();
         err_adj     .clear();
       }
+
+      double residual() const throw();
     };
 
     typedef std::vector<Observation> ObservationList;
@@ -177,6 +185,11 @@ namespace GNU_gama
 
     void init()  
     {
+      gons = true;
+
+      network_general_parameters.gama_local_version.  clear();
+      network_general_parameters.gama_local_algorithm.clear();
+      network_general_parameters.gama_local_compiler. clear();
       network_general_parameters.epoch.  clear();
       network_general_parameters.axes_xy.clear();
       network_general_parameters.angles. clear();
@@ -367,6 +380,8 @@ namespace GNU_gama
           s_point_end,
           s_id,
           s_id_end,
+          s_obs_id,
+          s_obs_id_end,
           s_x,
           s_x_end,
           s_y,
@@ -377,6 +392,8 @@ namespace GNU_gama
           s_orientation_shifts_end,
           s_orientation,
           s_orientation_end,
+          s_original_index,
+          s_original_index_end,
           s_ors_approx,
           s_ors_approx_end,
           s_ors_adj,
@@ -397,6 +414,8 @@ namespace GNU_gama
           s_from_end,
           s_to,
           s_to_end,
+          s_ind,
+          s_ind_end,
           s_left,
           s_left_end,
           s_right,
@@ -407,6 +426,8 @@ namespace GNU_gama
           s_obs_adj_end,
           s_stdev,
           s_stdev_end,
+          s_obs_qrr,
+          s_obs_qrr_end,
           s_obs_f,
           s_obs_f_end,
           s_std_residual,
@@ -468,6 +489,7 @@ namespace GNU_gama
           t_h_diffs,
           t_height_diff,
           t_id,
+          t_ind,
           t_left,
           t_lower,
           t_network_general_parameters,
@@ -478,10 +500,12 @@ namespace GNU_gama
           t_observations_summary,
           t_orientation_shifts,
           t_orientation,
+          t_original_index,
           t_passed,
           t_point,
           t_probability,
           t_project_equations,
+          t_qrr,
           t_ratio,
           t_right,
           t_s_dists,
@@ -550,6 +574,8 @@ namespace GNU_gama
       void directions(bool);
       void angles(bool);
       void xyz_coords(bool);
+      void id(bool);
+      void obs_id(bool);
       void h_diffs(bool);
       void z_angles(bool);
       void s_dists(bool);
@@ -578,7 +604,6 @@ namespace GNU_gama
       void approximate(bool);      
       void adjusted(bool);      
       void point(bool);      
-      void id(bool);      
       void x(bool);      
       void y(bool);      
       void z(bool);      
@@ -587,9 +612,11 @@ namespace GNU_gama
       void ors_approx(bool);      
       void ors_adj(bool);      
       void cov_mat(bool);      
+      void original_index(bool);      
       void dim(bool);      
       void band(bool);      
       void flt(bool);      
+      void ind(bool);      
       void observations(bool);
       void observation(bool);
       void from(bool);
@@ -599,6 +626,7 @@ namespace GNU_gama
       void obs(bool);
       void obs_adj(bool);
       void stdev(bool);
+      void obs_qrr(bool);
       void obs_f(bool);
       void std_residual(bool);
       void err_obs(bool);
