@@ -1,5 +1,5 @@
 /*  
-    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.00)
+    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
     Copyright (C) 1999, 2007  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Matrix/Vector template library.
@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: array.h,v 1.4 2007/12/01 20:21:17 cepek Exp $
+ *  $Id: array.h,v 1.5 2008/10/28 12:39:18 cepek Exp $
  *  http://www.gnu.org/software/gama/
  */
 
@@ -29,7 +29,7 @@
 
 #include <matvec/memrep.h>
 
-namespace GNU_gama {
+namespace GNU_gama {   /** \brief Dynamic array */
 
 template <typename Type, typename Exc=Exception::matvec>  
 class Array : public MemRep<Type, Exc> {
